==> install-mimic_0.4.1.orig.tar.xz: install-mimic-0.4.1/docs/download.md <==
<!--
SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
SPDX-License-Identifier: BSD-2-Clause
-->

# Download

These are the released versions of [install-mimic](index.md) available for download.

## [0.4.1] - 2024-02-26

- [install-mimic-0.4.1.tar.bz2](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.1.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.1.tar.bz2.asc))
- [install-mimic-0.4.1.tar.gz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.1.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.1.tar.gz.asc))
- [install-mimic-0.4.1.tar.xz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.1.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.1.tar.xz.asc))

## [0.4.0] - 2018-05-04

- [install-mimic-0.4.0.tar.bz2](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.0.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.0.tar.bz2.asc))
- [install-mimic-0.4.0.tar.gz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.0.tar.gz.asc))
- [install-mimic-0.4.0.tar.xz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.0.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.0.tar.xz.asc))

## [0.3.1] - 2017-09-29

- [install-mimic-0.3.1.tar.bz2](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.1.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.1.tar.bz2.asc))
- [install-mimic-0.3.1.tar.gz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.1.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.1.tar.gz.asc))
- [install-mimic-0.3.1.tar.xz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.1.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.1.tar.xz.asc))

## [0.3.0] - 2017-02-27

- [install-mimic-0.3.0.tar.bz2](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.0.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.0.tar.bz2.asc))
- [install-mimic-0.3.0.tar.gz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.0.tar.gz.asc))
- [install-mimic-0.3.0.tar.xz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.0.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.0.tar.xz.asc))

## [0.2.0] - 2016-06-29

- [install-mimic-0.2.0.tar.bz2](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.2.0.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.2.0.tar.bz2.asc))
- [install-mimic-0.2.0.tar.gz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.2.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.2.0.tar.gz.asc))
- [install-mimic-0.2.0.tar.xz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.2.0.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.2.0.tar.xz.asc))

## [0.1.1] - 2016-06-28

- [install-mimic-0.1.1.tar.bz2](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.1.1.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.1.1.tar.bz2.asc))
- [install-mimic-0.1.1.tar.gz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.1.1.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.1.1.tar.gz.asc))
- [install-mimic-0.1.1.tar.xz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.1.1.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.1.1.tar.xz.asc))

## [0.1.0] - 2015-06-02

- [install_mimic-0.1.0.tar.bz2](https://devel.ringlet.net/files/misc/install-mimic/install_mimic-0.1.0.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install_mimic-0.1.0.tar.bz2.asc))
- [install_mimic-0.1.0.tar.gz](https://devel.ringlet.net/files/misc/install-mimic/install_mimic-0.1.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install_mimic-0.1.0.tar.gz.asc))

[0.4.0]: https://github.com/ppentchev/install-mimic/releases/tag/release%2F0.4.0
[0.3.1]: https://github.com/ppentchev/install-mimic/releases/tag/release%2F0.3.1
[0.3.0]: https://github.com/ppentchev/install-mimic/releases/tag/release%2F0.3.0
[0.2.0]: https://github.com/ppentchev/install-mimic/releases/tag/release%2F0.2.0
[0.1.1]: https://github.com/ppentchev/install-mimic/releases/tag/release%2F0.1.1
[0.1.0]: https://github.com/ppentchev/install-mimic/releases/tag/release%2F0.1.0

==> install-mimic_0.4.2.orig.tar.xz: install-mimic-0.4.2/docs/download.md <==
<!--
SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
SPDX-License-Identifier: BSD-2-Clause
-->

# Download

These are the released versions of [install-mimic](index.md) available for download.

## [0.4.2] - 2025-03-15

- [install-mimic-0.4.2.tar.bz2](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.2.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.2.tar.bz2.asc))
- [install-mimic-0.4.2.tar.gz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.2.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.2.tar.gz.asc))
- [install-mimic-0.4.2.tar.xz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.2.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.2.tar.xz.asc))

## [0.4.1] - 2024-02-26

- [install-mimic-0.4.1.tar.bz2](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.1.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.1.tar.bz2.asc))
- [install-mimic-0.4.1.tar.gz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.1.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.1.tar.gz.asc))
- [install-mimic-0.4.1.tar.xz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.1.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.1.tar.xz.asc))

## [0.4.0] - 2018-05-04

- [install-mimic-0.4.0.tar.bz2](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.0.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.0.tar.bz2.asc))
- [install-mimic-0.4.0.tar.gz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.0.tar.gz.asc))
- [install-mimic-0.4.0.tar.xz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.0.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.4.0.tar.xz.asc))

## [0.3.1] - 2017-09-29

- [install-mimic-0.3.1.tar.bz2](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.1.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.1.tar.bz2.asc))
- [install-mimic-0.3.1.tar.gz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.1.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.1.tar.gz.asc))
- [install-mimic-0.3.1.tar.xz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.1.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.1.tar.xz.asc))

## [0.3.0] - 2017-02-27

- [install-mimic-0.3.0.tar.bz2](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.0.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.0.tar.bz2.asc))
- [install-mimic-0.3.0.tar.gz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.0.tar.gz.asc))
- [install-mimic-0.3.0.tar.xz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.0.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.3.0.tar.xz.asc))

## [0.2.0] - 2016-06-29

- [install-mimic-0.2.0.tar.bz2](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.2.0.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.2.0.tar.bz2.asc))
- [install-mimic-0.2.0.tar.gz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.2.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.2.0.tar.gz.asc))
- [install-mimic-0.2.0.tar.xz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.2.0.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.2.0.tar.xz.asc))

## [0.1.1] - 2016-06-28

- [install-mimic-0.1.1.tar.bz2](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.1.1.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.1.1.tar.bz2.asc))
- [install-mimic-0.1.1.tar.gz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.1.1.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.1.1.tar.gz.asc))
- [install-mimic-0.1.1.tar.xz](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.1.1.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install-mimic-0.1.1.tar.xz.asc))

## [0.1.0] - 2015-06-02

- [install_mimic-0.1.0.tar.bz2](https://devel.ringlet.net/files/misc/install-mimic/install_mimic-0.1.0.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install_mimic-0.1.0.tar.bz2.asc))
- [install_mimic-0.1.0.tar.gz](https://devel.ringlet.net/files/misc/install-mimic/install_mimic-0.1.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/misc/install-mimic/install_mimic-0.1.0.tar.gz.asc))

[0.4.2]: https://github.com/ppentchev/install-mimic/releases/tag/release%2F0.4.2
[0.4.1]: https://github.com/ppentchev/install-mimic/releases/tag/release%2F0.4.1
[0.4.0]: https://github.com/ppentchev/install-mimic/releases/tag/release%2F0.4.0
[0.3.1]: https://github.com/ppentchev/install-mimic/releases/tag/release%2F0.3.1
[0.3.0]: https://github.com/ppentchev/install-mimic/releases/tag/release%2F0.3.0
[0.2.0]: https://github.com/ppentchev/install-mimic/releases/tag/release%2F0.2.0
[0.1.1]: https://github.com/ppentchev/install-mimic/releases/tag/release%2F0.1.1
[0.1.0]: https://github.com/ppentchev/install-mimic/releases/tag/release%2F0.1.0
